@@ -103,13 +103,12 @@ def upload(project, logger, git_diff):
 
 
 @project_group.command()
-@click.option('-c', '--commit', default=None, help=messages.PROJECT_DOWNLOAD_HELP_COMMIT)
 @prepare_command()
-def download(project, logger, commit):
+def download(project, logger):
     """
     Downloads updated files to the current project folder
     """
-    project.download(progress_bar_enabled=True, commit_sha1=commit)
+    project.download(progress_bar_enabled=True)
     logger.log_and_echo(messages.DATA_DOWNLOAD_SUCCESS)
 
 
