@@ -47,23 +47,10 @@ class Config:
         else:
             self.root = ""
 
-        # Support legacy config files
+        # Load all relevant config config files
         self._load_legacy_config()
-
-        if self.global_config_exists:
-            global_config = yaml.safe_load(open(self.global_config_file_path, "r")) or {}
-            if global_config.get("token"):
-                self.is_capi = True
-
-            for key in Config.global_config_attributes.keys():
-                default = False if Config.global_config_attributes[key] == bool else None
-                self.global_config[key] = global_config.get(key, default) or self.global_config.get(key, default)
-
-        if self.local_config_exists:
-            local_config = yaml.safe_load(open(self.local_config_file_path, "r")) or {}
-            for key in Config.local_config_attributes.keys():
-                default = False if Config.local_config_attributes[key] == bool else None
-                self.local_config[key] = local_config.get(key, default) or self.local_config.get(key, default)
+        self._load_global_config()
+        self._load_local_config()
 
     @property
     def data_owner_slug(self):
@@ -77,7 +64,7 @@ class Config:
     def local_cnvrg_path(self):
         path = os.getcwd()
         # stop if we reach the home path to avoid the global .cnvrg
-        while str(path) not in ['~', '/', Path.home()]:
+        while str(path) not in ['~', '/', str(Path.home())]:
             joined_path = os.path.join(str(path), CONFIG_FOLDER_NAME)
             if os.path.exists(joined_path):
                 return joined_path
@@ -92,6 +79,14 @@ class Config:
     def global_config_file_path(self):
         return os.path.join(self.global_cnvrg_path, CONFIG_FILE_NAME)
 
+    @property
+    def legacy_global_config_file_path(self):
+        return os.path.join(self.global_cnvrg_path, LEGACY_CONFIG_FILE_NAME)
+
+    @property
+    def legacy_local_config_file_path(self):
+        return os.path.join(self.local_cnvrg_path, LEGACY_CONFIG_FILE_NAME)
+
     @property
     def local_config_exists(self):
         return os.path.exists(self.local_config_file_path)
@@ -100,21 +95,36 @@ class Config:
     def global_config_exists(self):
         return os.path.exists(self.global_config_file_path)
 
-    def _load_legacy_config(self):
-        legacy_global_config_file_path = os.path.join(self.global_cnvrg_path, LEGACY_CONFIG_FILE_NAME)
-        legacy_idx_file_path = os.path.join(self.local_cnvrg_path, LEGACY_IDX_FILE_NAME)
-        legacy_config_file_path = os.path.join(self.local_cnvrg_path, LEGACY_CONFIG_FILE_NAME)
+    def _load_global_config(self):
+        if self.global_config_exists:
+            global_config = yaml.safe_load(open(self.global_config_file_path, "r")) or {}
+            if global_config.get("token"):
+                self.is_capi = True
 
-        legacy_global_config_exists = os.path.exists(legacy_global_config_file_path)
+            for key in Config.global_config_attributes.keys():
+                default = False if Config.global_config_attributes[key] == bool else None
+                self.global_config[key] = global_config.get(key, default) or self.global_config.get(key, default)
+
+    def _load_local_config(self):
+        if self.local_config_exists:
+            local_config = yaml.safe_load(open(self.local_config_file_path, "r")) or {}
+            for key in Config.local_config_attributes.keys():
+                default = False if Config.local_config_attributes[key] == bool else None
+                self.local_config[key] = local_config.get(key, default) or self.local_config.get(key, default)
+
+    def _load_legacy_config(self):
+        legacy_idx_file_path = os.path.join(self.local_cnvrg_path, LEGACY_IDX_FILE_NAME)
+
+        legacy_global_config_exists = os.path.exists(self.legacy_global_config_file_path)
         legacy_netrc_exists = os.path.exists(LEGACY_NETRC_PATH)
 
         legacy_idx_exists = os.path.exists(legacy_idx_file_path)
-        legacy_config_exists = os.path.exists(legacy_config_file_path)
+        legacy_config_exists = os.path.exists(self.legacy_local_config_file_path)
 
         organization = None
         # We want to try and load legacy config file BEFORE the new config file so we can override if needed
         if legacy_global_config_exists:
-            legacy_global_config = yaml.safe_load(open(legacy_global_config_file_path, "r")) or {}
+            legacy_global_config = yaml.safe_load(open(self.legacy_global_config_file_path, "r")) or {}
             organization = legacy_global_config.get(":owner", None) or legacy_global_config.get("owner", None)
             api = legacy_global_config.get(":api", None) or legacy_global_config.get("api", None)
             uri = urllib.parse.urlparse(api)
@@ -130,7 +140,7 @@ class Config:
                 self.is_capi = False
 
         if legacy_config_exists:
-            legacy_config = yaml.safe_load(open(legacy_config_file_path, "r")) or {}
+            legacy_config = yaml.safe_load(open(self.legacy_local_config_file_path, "r")) or {}
             organization = legacy_config.get(":owner", None) or legacy_config.get("owner", None) or organization
             self.project_slug = legacy_config.get("project_slug", None) or legacy_config.get(":project_slug", None)
             self.library_slug = legacy_config.get("project_slug", None) or legacy_config.get(":library_slug", None)
