@@ -1,5 +1,5 @@
 # GLOBAL
-NO_FILE = "File not found"
+NO_FILE = "File not found. Please check the file path"
 NO_DIR = "Directory not found"
 
 # VALIDATIONS
@@ -121,6 +121,8 @@ WORKFLOW_FINAL_STATE = "Workflow reached a final state {0}, different from desir
 
 # FLOW
 FLOW_GET_FAULTY_SLUG = "Cannot get flows with empty slug or a non string slug"
+FLOW_GET_FAULTY_YAML = "Yaml is not valid"
+FLOW_GET_FAULTY_INPUT = "Only one parameter is expected. Please resend the request with only one parameter"
 
 # FLOW_VERSION
 FLOW_VERSION_GET_FAULTY_SLUG = "Cannot get flows version with empty slug or a non string slug"
