@@ -78,8 +78,6 @@ class ArtifactsDownloader(RemoteFilesHandler):
         @param page_after: The id of the next file that the iteration of the pagination should start from
         @return: Should return array of files metadata
         """
-        if not self.base_commit_sha1:
-            raise AttributeError("base commit must be sent")
 
         response = self.data_owner._proxy.call_api(
             route=self.compare_url.format(page_after, 1000, self.mode),
