@@ -1,6 +1,7 @@
-import urllib3
 import warnings
 
+import urllib3
+
 storage_clients_imports = [
     "from cnvrgv2.data.clients.s3.client import S3Storage",
     "from cnvrgv2.data.clients.azure.client import AzureStorage",
@@ -32,17 +33,20 @@ STORAGE_TYPE_S3 = "s3"
 STORAGE_TYPE_MINIO = "minio"
 
 
-def storage_client_factory(storage_meta):
+def storage_client_factory(refresh_function):
     """
     Returns the relevant storage client depending on the storage meta got from the server
-    @param storage_meta: Dataset storage meta dictionary
-    @param working_dir: The local data directory
+    @param refresh_function: Function that fetches dataset storage meta dictionary
     @return: storage client of type <BaseStorageClient>
     """
+    storage_meta = refresh_function()
+
     if storage_meta is None:
         return None
+
+    # TODO: change all storage types to use refresh_function
     if storage_meta.get("storage") == STORAGE_TYPE_S3:
-        return S3Storage(storage_meta)
+        return S3Storage(refresh_function)
     if storage_meta.get("storage") == STORAGE_TYPE_MINIO:
         return MinioStorage(storage_meta)
     if storage_meta.get("storage") == STORAGE_TYPE_AZURE:
