@@ -472,12 +472,11 @@ class DataOwner(DynamicAttributes):
         self.save_config()
         os.chdir(old_working_dir)
 
-    def download(self, sync=False, progress_bar_enabled=False, commit_sha1=None):
+    def download(self, sync=False, progress_bar_enabled=False):
         """
         Download files from remote project / dataset
         @param sync: Boolean gives info if the put files comes from sync or not
         @param progress_bar_enabled: Boolean indicating whenever or not to print a progress bar. In use of the cli
-        @param commit_sha1: Sha1 of a specific commit to download
         @return: None
         """
         # We want to make sure we are in a project/dataset folder in order to continue with the action
@@ -501,7 +500,7 @@ class DataOwner(DynamicAttributes):
         downloader = ArtifactsDownloader(
             self,
             base_commit_sha1=self.local_commit,
-            commit_sha1=commit_sha1 or self.last_commit,
+            commit_sha1=self.last_commit,
             progress_bar_enabled=progress_bar_enabled
         )
         while downloader.in_progress:
@@ -524,7 +523,7 @@ class DataOwner(DynamicAttributes):
 
         if not sync:
             self.move_files_from_tmp()
-            self.local_commit = commit_sha1 or self.last_commit
+            self.local_commit = self.last_commit
             self.save_config()
 
         os.chdir(context_working_dir)
