@@ -55,7 +55,7 @@ class LibraryVersion(DynamicAttributes):
         destination = "{0}{1}".format(destination_prefix, self._context.library)
 
         if not os.path.isdir(destination):
-            os.mkdir(working_dir)
+            os.mkdir(destination)
 
         response = requests.get(self.files_download_link, allow_redirects=True, stream=True)
         total_length = response.headers.get('content-length')
