@@ -1,13 +1,13 @@
-from cnvrgv2.proxy import Proxy, HTTP
-from cnvrgv2.utils.json_api_format import JAF
-from cnvrgv2.config import routes, error_messages
-from cnvrgv2.utils.validators import validate_email, validate_user_role
 from cnvrgv2 import cnvrg
-from cnvrgv2.utils.api_list_generator import api_list_generator
-from cnvrgv2.modules.members import Member
+from cnvrgv2.config import error_messages, routes
+from cnvrgv2.config.error_messages import FAULTY_VALUE
 from cnvrgv2.context import Context, SCOPE
 from cnvrgv2.errors import CnvrgArgumentsError
-from cnvrgv2.config.error_messages import FAULTY_VALUE
+from cnvrgv2.modules.members import Member
+from cnvrgv2.proxy import HTTP, Proxy
+from cnvrgv2.utils.api_list_generator import api_list_generator
+from cnvrgv2.utils.json_api_format import JAF
+from cnvrgv2.utils.validators import validate_email, validate_user_role
 
 
 class MembersClient:
@@ -75,4 +75,3 @@ class MembersClient:
             sort=sort,
             filter=filter
         )
-
