@@ -1,12 +1,15 @@
-from cnvrgv2.config import routes, error_messages
-from cnvrgv2.proxy import Proxy, HTTP
-from cnvrgv2.errors import CnvrgError, CnvrgArgumentsError
+import os
+
+import yaml
+
+from cnvrgv2.config import error_messages, routes
 from cnvrgv2.context import Context, SCOPE
+from cnvrgv2.errors import CnvrgArgumentsError, CnvrgError
 from cnvrgv2.modules.base.dynamic_attributes import DynamicAttributes
 from cnvrgv2.modules.resources.templates.kube_templates_client import KubeTemplatesClient
+from cnvrgv2.proxy import HTTP, Proxy
 from cnvrgv2.utils.url_utils import urljoin
-import yaml
-import os
+
 
 class Cluster(DynamicAttributes):
     available_attributes = {
@@ -46,7 +49,7 @@ class Cluster(DynamicAttributes):
         Deletes the current cluster
         @return: None
         """
-        #todo: change routes without resource_request
+        # TODO: change routes without resource_request
         scope = self._context.get_scope(SCOPE.RESOURCE)
         base_route = routes.CLUSTERS_BASE.format(scope["organization"])
         route = urljoin(base_route, routes.CLUSTER_RESOURCE_REQUEST, self.slug)
