@@ -1,13 +1,14 @@
 import json
+from collections import OrderedDict
+
 import requests
 
-from collections import OrderedDict
 from cnvrgv2._version import __version__
+from cnvrgv2.config import Config
 from cnvrgv2.config import error_messages
 from cnvrgv2.errors import CnvrgError, CnvrgHttpError, ExceptionsConfig
-from cnvrgv2.config import Config
-from cnvrgv2.utils.url_utils import urljoin
 from cnvrgv2.utils.json_api_format import JAF
+from cnvrgv2.utils.url_utils import urljoin
 
 
 class HTTP:
@@ -147,6 +148,6 @@ class Proxy:
         error_string = ""
         errors = response["errors"]
         for error in errors:
-            error_string += error.get("title", "") + " " + error.get("detail", "")
+            error_string += error.get("title", "") + ": " + error.get("detail", "")
 
         return error_string
